@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-history-entry.c 6112 2008-01-23 08:26:24Z sfre $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -260,6 +260,7 @@ gedit_history_entry_save_history (GeditHistoryEntry *entry)
 			      gconf_items,
 			      NULL);
 
+	g_slist_foreach (gconf_items, (GFunc) g_free, NULL);
 	g_slist_free (gconf_items);
 	g_free (key);
 }
@@ -289,9 +290,12 @@ remove_item (GtkListStore *store,
 		    strcmp (item_text, text) == 0)
 		{
 			gtk_list_store_remove (store, &iter);
+			g_free (item_text);
 			return TRUE;
 		}
 
+		g_free (item_text);
+
 	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter));
 
 	return FALSE;
@@ -382,7 +386,7 @@ gedit_history_entry_load_history (GeditHistoryEntry *entry)
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gchar *key;
-	gint i;
+	guint i;
 
 	g_return_if_fail (GEDIT_IS_HISTORY_ENTRY (entry));
 
@@ -408,8 +412,9 @@ gedit_history_entry_load_history (GeditHistoryEntry *entry)
 				    -1);
 	}
 
-	g_free (key);
+	g_slist_foreach (gconf_items, (GFunc) g_free, NULL);
 	g_slist_free (gconf_items);
+	g_free (key);
 }
 
 void
